FieldOfView
===========

.. currentmodule:: pywwt.annotation

.. autoclass:: FieldOfView
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~FieldOfView.remove

   .. rubric:: Methods Documentation

   .. automethod:: remove
